@@ -7,6 +7,7 @@
 #' @template roxlate-ml-features
 #' @template roxlate-ml-intercept
 #' @template roxlate-ml-regression-penalty
+#' @template roxlate-ml-weights-column
 #' @template roxlate-ml-iter-max
 #' @template roxlate-ml-options
 #' @template roxlate-ml-dots
@@ -20,6 +21,7 @@ ml_logistic_regression <- function(x,
                                    intercept = TRUE,
                                    alpha = 0,
                                    lambda = 0,
+                                   weights.column = NULL,
                                    iter.max = 100L,
                                    ml.options = ml_options(),
                                    ...)
@@ -42,6 +44,7 @@ ml_logistic_regression <- function(x,
 
   alpha <- ensure_scalar_double(alpha)
   lambda <- ensure_scalar_double(lambda)
+  weights.column <- ensure_scalar_character(weights.column, allow.null = TRUE)
   iter.max <- ensure_scalar_integer(iter.max)
   only.model <- ensure_scalar_boolean(ml.options$only.model)
 
@@ -65,41 +68,88 @@ ml_logistic_regression <- function(x,
     invoke("setElasticNetParam", as.double(alpha)) %>%
     invoke("setRegParam", as.double(lambda))
 
-  if (only.model) return(model)
+  if (!is.null(weights.column)) {
+    model <- model %>%
+      invoke("setWeightCol", weights.column)
+  }
+
+  if (only.model)
+    return(model)
 
   fit <- model %>%
     invoke("fit", tdf)
 
-  coefficients <- fit %>%
-    invoke("coefficients") %>%
-    invoke("toArray")
-  names(coefficients) <- features
+  # multinomial vs. binomial models have separate APIs for
+  # retrieving results
+  numClasses <- invoke(fit, "numClasses")
+  isMultinomial <- numClasses > 2
+
+  # extract coefficients (can be either a vector or matrix, depending
+  # on binomial vs. multinomial)
+  coefficients <- if (isMultinomial) {
+
+    if (spark_version(sc) < "2.1.0") stop("Multinomial regression requires Spark 2.1.0 or higher.")
+
+    # multinomial
+    coefficients <- read_spark_matrix(fit, "coefficientMatrix")
+    colnames(coefficients) <- features
+
+    hasIntercept <- invoke(fit, "getFitIntercept")
+    if (hasIntercept) {
+      intercept <- read_spark_vector(fit, "interceptVector")
+      coefficients <- cbind(intercept, coefficients)
+      colnames(coefficients) <- c("(Intercept)", features)
+    }
+
+    coefficients
+
+  } else {
+
+    coefficients <- read_spark_vector(fit, "coefficients")
+
+    hasIntercept <- invoke(fit, "getFitIntercept")
+    if (hasIntercept) {
+      intercept <- invoke(fit, "intercept")
+      coefficients <- c(coefficients, intercept)
+      names(coefficients) <- c(features, "(Intercept)")
+    }
+
+    coefficients <- intercept_first(coefficients)
+    coefficients
 
-  hasIntercept <- invoke(fit, "getFitIntercept")
-  if (hasIntercept) {
-    intercept <- invoke(fit, "intercept")
-    coefficients <- c(coefficients, intercept)
-    names(coefficients) <- c(features, "(Intercept)")
   }
 
-  summary <- invoke(fit, "summary")
-  areaUnderROC <- invoke(summary, "areaUnderROC")
-  roc <- sdf_collect(invoke(summary, "roc"))
+  # multinomial models don't yet provide a 'summary' method
+  # (as of Spark 2.1.0) so certain features will not be enabled
+  # for those models
+  areaUnderROC <- NA
+  roc <- NA
+  if (invoke(fit, "hasSummary")) {
+    summary <- invoke(fit, "summary")
+    areaUnderROC <- invoke(summary, "areaUnderROC")
+    roc <- sdf_collect(invoke(summary, "roc"))
+  }
 
-  coefficients <- intercept_first(coefficients)
+  model <- c(
+    if (isMultinomial)
+      "multinomial_logistic_regression"
+    else
+      "binomial_logistic_regression",
+    "logistic_regression"
+  )
 
-  ml_model("logistic_regression", fit,
+  ml_model(model, fit,
            features = features,
            response = response,
            intercept = intercept,
+           weights.column = weights.column,
            coefficients = coefficients,
            roc = roc,
            area.under.roc = areaUnderROC,
            data = df,
            ml.options = ml.options,
            categorical.transformations = categorical.transformations,
-           model.parameters = as.list(envir)
-  )
+           model.parameters = as.list(envir))
 }
 
 #' @export
@@ -124,9 +174,3 @@ summary.ml_model_logistic_regression <- function(object, ...) {
   print_newline()
 }
 
-
-#' @export
-residuals.ml_model_logistic_regression <- function(object, ...) {
-  stop("residuals not yet available for Spark logistic regression")
-}
-
